@@ -18,11 +18,11 @@ Params::Validate::Strict - Validates a set of parameters against a schema
 
 =head1 VERSION
 
-Version 0.09
+Version 0.10
 
 =cut
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 =head1 SYNOPSIS
 
@@ -180,7 +180,10 @@ sub validate_strict
 	if(ref($schema) ne 'HASH') {
 		croak 'validate_strict: schema must be a hash reference';
 	}
-	if(ref($args) ne 'HASH') {
+
+	if(exists($params->{'args'}) && (!defined($args))) {
+		$args = {};
+	} elsif(ref($args) ne 'HASH') {
 		croak 'validate_strict: args must be a hash reference';
 	}
 
@@ -250,6 +253,9 @@ sub validate_strict
 						}
 						$value = int($value); # Coerce to integer
 					} elsif($type eq 'number') {
+						if(!defined($value)) {
+							next;	# Skip if string is undefined
+						}
 						if(!Scalar::Util::looks_like_number($value)) {
 							croak(__PACKAGE__, "::validate_strict: Parameter '$key' must be a number");
 						}
@@ -297,6 +303,9 @@ sub validate_strict
 							croak("validate_strict: Parameter '$key' must contain at least $rule_value keys");
 						}
 					} elsif(($rules->{'type'} eq 'integer') || ($rules->{'type'} eq 'number')) {
+						if(!defined($value)) {
+							next;	# Skip if hash is undefined
+						}
 						if($value < $rule_value) {
 							croak(__PACKAGE__, "::validate_strict: Parameter '$key' must be at least $rule_value");
 						}
@@ -326,6 +335,9 @@ sub validate_strict
 							croak("validate_strict: Parameter '$key' must contain no more than $rule_value keys");
 						}
 					} elsif(($rules->{'type'} eq 'integer') || ($rules->{'type'} eq 'number')) {
+						if(!defined($value)) {
+							next;	# Skip if hash is undefined
+						}
 						if($value > $rule_value) {
 							croak(__PACKAGE__, "::validate_strict: Parameter '$key' must be no more than $rule_value");
 						}
